.. pandora_plugin_libsgm documentation master file, created by
   sphinx-quickstart on Mon May 18 11:40:41 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pandora_plugin_libsgm's documentation!
=================================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started.rst
   api_reference/index.rst
   developer_guide



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
